@@ -14,15 +14,16 @@
 #   See the License for the specific language governing permissions and
 #   limitations under the Licens
 #
-__author__ = 'Andrea Bonomi <andrea.bonomi@gmail.com>'
-__version__ = '3.3.3'
 
 from flask import Blueprint
 from airflow.plugins_manager import AirflowPlugin
-from airflow_code_editor.commons import STATIC
+from airflow_code_editor.commons import STATIC, VERSION
 from airflow_code_editor.flask_admin_view import admin_view
 from airflow_code_editor.app_builder_view import appbuilder_view
 
+__author__ = 'Andrea Bonomi <andrea.bonomi@gmail.com>'
+__version__ = VERSION
+
 __all__ = ['CodeEditorPlugin']
 
 
