@@ -15,6 +15,8 @@
 #   limitations under the Licens
 #
 
+import os
+
 __all__ = [
     'PLUGIN_NAME',
     'MENU_CATEGORY',
@@ -28,6 +30,8 @@ __all__ = [
     'PLUGIN_DEFAULT_CONFIG',
     'ROOT_MOUNTPOUNT',
     'JS_FILES',
+    'VERSION_FILE',
+    'VERSION',
 ]
 
 PLUGIN_NAME = 'code_editor'
@@ -56,6 +60,7 @@ SUPPORTED_GIT_COMMANDS = [
     'unstage',
 ]
 PLUGIN_DEFAULT_CONFIG = {
+    'git_enabled': True,
     'git_cmd': 'git',
     'git_default_args': '-c color.ui=true',
     'git_author_name': None,
@@ -82,11 +87,17 @@ JS_FILES = [
     'addon/search/jump-to-line.js',
     'mode/meta.js',
     'bootstrap-dialog.js',
+    'splitpanes.js',
     'vim.js',
     'emacs.js',
     'sublime.js',
     'vue.js',
+    'vue-tree.js',
     'themes.js',
     'gitweb.js',
     'vue_components.js',
 ]
+
+VERSION_FILE = os.path.join(os.path.dirname(__file__), "VERSION")
+with open(VERSION_FILE) as f:
+    VERSION = f.read().strip()
