@@ -21,10 +21,11 @@ import subprocess
 import threading
 import shlex
 import shutil
+from typing import Any, Dict, List, Optional, Tuple
 from datetime import datetime
 from collections import namedtuple
 from flask import jsonify, make_response
-from flask_login import current_user
+from flask_login import current_user  # type: ignore
 from airflow import configuration
 from airflow_code_editor.commons import (
     HTTP_200_OK,
@@ -48,9 +49,9 @@ __all__ = [
 ]
 
 
-def normalize_path(path):
+def normalize_path(path: Optional[str]) -> str:
     comps = (path or '/').split('/')
-    result = []
+    result: List[str] = []
     for comp in comps:
         if comp in ('', '.'):
             pass
@@ -61,26 +62,81 @@ def normalize_path(path):
     return '/'.join(result)
 
 
-def get_plugin_config(key):
+def get_plugin_config(key: str) -> str:
     " Get a plugin configuration/default for a given key "
     return configuration.conf.get(PLUGIN_NAME, key, fallback=PLUGIN_DEFAULT_CONFIG[key])
 
 
-def get_plugin_boolean_config(key):
+def get_plugin_boolean_config(key: str) -> bool:
     " Get a plugin boolean configuration/default for a given key "
     return configuration.conf.getboolean(
         PLUGIN_NAME, key, fallback=PLUGIN_DEFAULT_CONFIG[key]
     )
 
 
-def get_plugin_int_config(key):
+def get_plugin_int_config(key: str) -> int:
     " Get a plugin int configuration/default for a given key "
     return configuration.conf.getint(
         PLUGIN_NAME, key, fallback=PLUGIN_DEFAULT_CONFIG[key]
     )
 
 
-def prepare_git_response(git_cmd, result=None, stderr=None, returncode=0):
+def prepare_git_env() -> Dict[str, str]:
+    " Prepare the environ for git "
+    env = dict(os.environ)
+    # Author
+    git_author_name = get_plugin_config('git_author_name')
+    if not git_author_name:
+        try:
+            git_author_name = '%s %s' % (
+                current_user.first_name,
+                current_user.last_name,
+            )
+        except Exception:
+            pass
+    if git_author_name:
+        env['GIT_AUTHOR_NAME'] = git_author_name
+        env['GIT_COMMITTER_NAME'] = git_author_name
+    # Email
+    git_author_email = get_plugin_config('git_author_email')
+    if not git_author_email:
+        try:
+            git_author_email = current_user.email
+        except Exception:
+            pass
+    if git_author_email:
+        env['GIT_AUTHOR_EMAIL'] = git_author_email
+        env['GIT_COMMITTER_EMAIL'] = git_author_email
+    return env
+
+
+def get_root_folder() -> str:
+    " Return the configured root folder or Airflow DAGs folder "
+    return os.path.abspath(
+        get_plugin_config('root_directory')
+        or configuration.conf.get('core', 'dags_folder')
+    )
+
+
+def git_absolute_path(git_path: Optional[str]) -> str:
+    " Git relative path to absolute path "
+    path: str = normalize_path(git_path)
+    if path.startswith('~'):
+        # Expand paths beginning with '~'
+        prefix, remain = path.split('/', 1) if '/' in path else (path, '')
+        try:
+            return os.path.join(mount_points[prefix[1:]].path, remain)
+        except KeyError:
+            pass
+    return os.path.join(get_root_folder(), path)
+
+
+def prepare_git_response(
+    git_cmd: str,
+    result: Optional[bytes] = None,
+    stderr: Optional[bytes] = None,
+    returncode: int = 0,
+):
     if result is None:
         result = stderr
     elif stderr:
@@ -97,70 +153,18 @@ def prepare_git_response(git_cmd, result=None, stderr=None, returncode=0):
     return response
 
 
-def prepare_git_env():
-    " Prepare the environ for git "
-    env = dict(os.environ)
-    git_author_name = get_plugin_config('git_author_name')
-    if not git_author_name:
-        try:
-            git_author_name = '%s %s' % (
-                current_user.first_name,
-                current_user.last_name,
-            )
-        except Exception:
-            pass
-    if git_author_name:
-        env['GIT_AUTHOR_NAME'] = git_author_name
-        env['GIT_COMMITTER_NAME'] = git_author_name
-    git_author_email = get_plugin_config('git_author_email')
-    if not git_author_email:
-        try:
-            git_author_email = current_user.email
-        except Exception:
-            pass
-    if git_author_email:
-        env['GIT_AUTHOR_EMAIL'] = git_author_email
-        env['GIT_COMMITTER_EMAIL'] = git_author_email
-    return env
-
-
-def get_root_folder():
-    " Return the configured root folder or Airflow DAGs folder "
-    return os.path.abspath(
-        get_plugin_config('root_directory')
-        or configuration.conf.get('core', 'dags_folder')
-    )
-
-
-def git_absolute_path(git_path):
-    " Git relative path to absolute path "
-    path = normalize_path(git_path)
-    if path.startswith('~'):
-        # Expand paths beginning with '~'
-        prefix, remain = path.split('/', 1) if '/' in path else (path, '')
-        try:
-            return os.path.join(mount_points[prefix[1:]].path, remain)
-        except KeyError:
-            pass
-    return os.path.join(get_root_folder(), path)
-
-
 _execute_git_command_lock = threading.Lock()
 
 
-def execute_git_command(git_args):
+def execute_git_command(git_args: List[str]):
     with _execute_git_command_lock:
         logging.info(' '.join(git_args))
         git_cmd = git_args[0] if git_args else None
         stderr = None
         returncode = 0
         try:
-            cwd = get_root_folder()
             # Init git repo
-            if not os.path.exists(
-                os.path.join(cwd, '.git')
-            ) and get_plugin_boolean_config('git_init_repo'):
-                init_git_repo()
+            init_git_repo()
             # Local commands
             if git_cmd in LOCAL_COMMANDS:
                 handler = LOCAL_COMMANDS[git_cmd]
@@ -168,20 +172,14 @@ def execute_git_command(git_args):
             # Git commands
             elif git_cmd in SUPPORTED_GIT_COMMANDS:
                 git_default_args = shlex.split(get_plugin_config('git_default_args'))
-                cmd = [get_plugin_config('git_cmd')] + git_default_args + git_args
-                git = subprocess.Popen(
-                    cmd,
-                    stdin=subprocess.PIPE,
-                    stdout=subprocess.PIPE,
-                    stderr=subprocess.PIPE,
-                    cwd=cwd,
-                    env=prepare_git_env(),
+                returncode, stdout, stderr = git_call(
+                    git_default_args + git_args, capture_output=True
                 )
-                stdout, stderr = git.communicate()
-                returncode = git.returncode
             else:
                 stdout = None
-                stderr = 'Command not supported: git %s' % ' '.join(git_args)
+                stderr = bytes(
+                    'Command not supported: git %s' % ' '.join(git_args), 'utf-8'
+                )
                 returncode = 1
         except OSError as ex:
             logging.error(ex)
@@ -216,7 +214,7 @@ def git_ls_local(git_args):
             type_ = 'tree'
             try:
                 size_ = len(os.listdir(fullname))
-            except:
+            except Exception:
                 size_ = '-'
         else:
             type_ = 'blob'
@@ -269,26 +267,53 @@ LOCAL_COMMANDS = {
 }
 
 
-def init_git_repo():
+def git_call(argv: List[str], capture_output: bool = False) -> Tuple[int, bytes, bytes]:
+    " Run git command. If capture_output is true, stdout and stderr will be captured. "
+    if not get_plugin_boolean_config('git_enabled'):
+        return 1, '', 'Git is disabled'
+    cmd: List[str] = [get_plugin_config('git_cmd')] + argv
+    cwd: str = get_root_folder()
+    env: Dict[str, str] = prepare_git_env()
+    if capture_output:
+        git = subprocess.Popen(
+            cmd,
+            stdin=subprocess.PIPE,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+            cwd=cwd,
+            env=env,
+        )
+        stdout, stderr = git.communicate()
+        returncode: int = git.returncode
+    else:
+        stdout = b''
+        stderr = b''
+        returncode = subprocess.call(cmd, cwd=cwd, env=env)
+    return returncode, stdout, stderr
+
+
+def init_git_repo() -> None:
     " Initialize the git repository in root folder "
-    cwd = get_root_folder()
-    subprocess.call(['git', 'init', '.'], cwd=cwd)
-    gitignore = os.path.join(cwd, '.gitignore')
-    if not os.path.exists(gitignore):
-        with open(gitignore, 'w') as f:
-            f.write('__pycache__\n')
-        subprocess.call(['git', 'add', '.gitignore'], cwd=cwd)
-    subprocess.call(
-        ['git', 'commit', '-m', 'Initial commit'], cwd=cwd, env=prepare_git_env()
-    )
+    cwd: str = get_root_folder()
+    if (
+        get_plugin_boolean_config('git_enabled')
+        and not os.path.exists(os.path.join(cwd, '.git'))
+        and get_plugin_boolean_config('git_init_repo')
+    ):
+        git_call(['init', '.'])
+        gitignore = os.path.join(cwd, '.gitignore')
+        if not os.path.exists(gitignore):
+            with open(gitignore, 'w') as f:
+                f.write('__pycache__\n')
+            git_call(['add', '.gitignore'])
+        git_call(['commit', '-m', 'Initial commit'], env=prepare_git_env())
 
 
 MountPoint = namedtuple('MountPoint', 'path default')
 
 
-def read_mount_points_config():
+def read_mount_points_config() -> Dict[str, MountPoint]:
     " Return the plugin configuration "
-    global mount_points
     config = {ROOT_MOUNTPOUNT: MountPoint(path=get_root_folder(), default=True)}
     i = 0
     # Iterate over the configurations
@@ -307,13 +332,13 @@ def read_mount_points_config():
         path = configuration.conf.get(PLUGIN_NAME, 'mount{}_path'.format(suffix))
         config[name] = MountPoint(path=path, default=False)
         i = i + 1
-    mount_points = config
+    return config
 
 
-read_mount_points_config()
+mount_points = read_mount_points_config()
 
 
-def error_message(ex: Exception):
+def error_message(ex: Exception) -> str:
     " Get exception error message "
     if ex is None:
         return ''
